/*
 * <LH:881125:v2.0>
 */

#include <sys/types.h>
#include <sys/stat.h>
#include <sys/ipc.h>
#include <sys/msg.h>
#include <sys/errno.h>
#include <ctype.h>
#include <curses.h>
#include <signal.h>
#include <pwd.h>
#include <utmp.h>


/* window sizes */

#define         MY_WINLINES              (LINES / 2)
#define         HIS_WINLINES             (LINES - MY_WINLINES - 1)


/*  Message queue commands 	<LH:881125:v2.0>	*/

#define		CONNECT			0xF0
#define		DISCONNECT		0xF3
#define		DELETE			0xFC
#define		END_OF_FILE		0x04
#define		REFRESH			0x0C
#define		BELL			0x07


/*  Exit codes 			<LH:881125:v2.0>	*/

#define		I_DISCONNECTED		1
#define		HE_DISCONNECTED		2
#define		NO_ANSWER		3
#define		NOT_LOGGED_IN		4
#define		TTY_DISABLED		5
#define		PROGRAM_ERROR		6


/* other defines		<LH:881125:v2.0>	*/

#define		TIME_SIZE		19	/* size of window clock */
#define		TICK_INTERVAL		2	/* clock update interval */
#define		MAXTRY			3	/* max tries to notify user */
#define		TRY_TIME		20	/* time between tries */


/* message queue defines	<LH:881125:v2.0>	*/

#define		MSGSIZE			(sizeof (MSG) - sizeof (long))
#define		ANYMSG			(0)
#define		MSGMASK			0600


/* macros			<LH:881125:v2.0>	*/

#define		printable(x)		(x == '\n' || x == '\t' || isprint(x)) 
#define		file_exist(x)		(access(x, 0) == 0)
#define		eq(s1,s2)		(strcmp(s1,s2) == 0)


/* variable and function declarations  <LH:881125:v2.0>	*/

extern	WINDOW	*mywin, *hiswin, *dividewin;	/*  the three windows  */
extern	int	connected;			/* whether actually talking  */
extern	int	time_changed;			/*  to update elapsed time  */
extern	int	master;				/*  whether master or slave  */
extern	int	msgid;				/*  message queue id */

extern	long	time();
extern	int	out_of_date();
extern	void	clock_tick();
extern	void	interrupt();			/* intr trap (disconnect) */
extern	void	disconnect();
extern	void	doconnect();
extern	void	talk();
extern	void	update_time();
extern	void	screen_init();
extern	void	master_queue();
extern	void	slave_queue();
extern	void	error();
extern	void	sendmsg();
extern	void	setutent();
extern	void	add_my_window();
extern	void	add_his_window();
extern	void	wheader();
extern	void	wprevch();
extern	void	update_time_line();

extern	char	*notify();			/*  ring user */
extern	char	*fullname();			/*  full name of login name */
extern	char	*ctime();			/*  get current time str */
extern	char	*strchr();
extern	char	*strrchr();
extern	char	*getlogin();

extern	struct	utmp *getutent();
extern	struct	passwd *getpwnam();

extern	int	mypid;				/*  current PID */
extern	int	readpid;			/*  current keyboard PID */
extern	int	hispid;				/*  other sides PID */
extern	int	errno;

extern	key_t	key;				/*  common key for msgget() */

extern	char	tmp[BUFSIZ];			/*  general purpose !  */
extern	char	tempfile[40];			/*  common temp file */
extern	char	*myname, *hisname, *histty;
extern	char	*progname;			/*  current program name */
extern	char	delchar;			/*  current delete char  */


/*
 * Message queue buffer.  <LH-881125>
 *
 * Messages are sent from your own keyboard-read process to your own displays
 * process (se talk.c). Your display-process will first show it on your window
 * and then send it over to the other side. Messages comming from the other
 * side (i.e: msg.from_pid == hispid) will show up at "his" window.
 */

typedef struct _msg
{
	long	to_pid;			/* want only messages to this PID */
	int	from_pid;		/* PID who sent message */
	int	c;			/* the actual character (or cmd) */
} MSG;

extern	MSG	*getmsg();
